package de.doubleslash.service.persistence;

import com.liferay.portal.service.persistence.BasePersistence;

import de.doubleslash.model.Demo;

/**
 * The persistence interface for the demo service.
 *
 * <p>
 * Caching information and settings can be found in <code>portal.properties</code>
 * </p>
 *
 * @author Brian Wing Shun Chan
 * @see DemoPersistenceImpl
 * @see DemoUtil
 * @generated
 */
public interface DemoPersistence extends BasePersistence<Demo> {
    /*
     * NOTE FOR DEVELOPERS:
     *
     * Never modify or reference this interface directly. Always use {@link DemoUtil} to access the demo persistence. Modify <code>service.xml</code> and rerun ServiceBuilder to regenerate this interface.
     */

    /**
    * Returns the demo where demoId = &#63; or throws a {@link de.doubleslash.NoSuchDemoException} if it could not be found.
    *
    * @param demoId the demo ID
    * @return the matching demo
    * @throws de.doubleslash.NoSuchDemoException if a matching demo could not be found
    * @throws SystemException if a system exception occurred
    */
    public de.doubleslash.model.Demo findBydemoId(long demoId)
        throws com.liferay.portal.kernel.exception.SystemException,
            de.doubleslash.NoSuchDemoException;

    /**
    * Returns the demo where demoId = &#63; or returns <code>null</code> if it could not be found. Uses the finder cache.
    *
    * @param demoId the demo ID
    * @return the matching demo, or <code>null</code> if a matching demo could not be found
    * @throws SystemException if a system exception occurred
    */
    public de.doubleslash.model.Demo fetchBydemoId(long demoId)
        throws com.liferay.portal.kernel.exception.SystemException;

    /**
    * Returns the demo where demoId = &#63; or returns <code>null</code> if it could not be found, optionally using the finder cache.
    *
    * @param demoId the demo ID
    * @param retrieveFromCache whether to use the finder cache
    * @return the matching demo, or <code>null</code> if a matching demo could not be found
    * @throws SystemException if a system exception occurred
    */
    public de.doubleslash.model.Demo fetchBydemoId(long demoId,
        boolean retrieveFromCache)
        throws com.liferay.portal.kernel.exception.SystemException;

    /**
    * Removes the demo where demoId = &#63; from the database.
    *
    * @param demoId the demo ID
    * @return the demo that was removed
    * @throws SystemException if a system exception occurred
    */
    public de.doubleslash.model.Demo removeBydemoId(long demoId)
        throws com.liferay.portal.kernel.exception.SystemException,
            de.doubleslash.NoSuchDemoException;

    /**
    * Returns the number of demos where demoId = &#63;.
    *
    * @param demoId the demo ID
    * @return the number of matching demos
    * @throws SystemException if a system exception occurred
    */
    public int countBydemoId(long demoId)
        throws com.liferay.portal.kernel.exception.SystemException;

    /**
    * Caches the demo in the entity cache if it is enabled.
    *
    * @param demo the demo
    */
    public void cacheResult(de.doubleslash.model.Demo demo);

    /**
    * Caches the demos in the entity cache if it is enabled.
    *
    * @param demos the demos
    */
    public void cacheResult(java.util.List<de.doubleslash.model.Demo> demos);

    /**
    * Creates a new demo with the primary key. Does not add the demo to the database.
    *
    * @param demoId the primary key for the new demo
    * @return the new demo
    */
    public de.doubleslash.model.Demo create(long demoId);

    /**
    * Removes the demo with the primary key from the database. Also notifies the appropriate model listeners.
    *
    * @param demoId the primary key of the demo
    * @return the demo that was removed
    * @throws de.doubleslash.NoSuchDemoException if a demo with the primary key could not be found
    * @throws SystemException if a system exception occurred
    */
    public de.doubleslash.model.Demo remove(long demoId)
        throws com.liferay.portal.kernel.exception.SystemException,
            de.doubleslash.NoSuchDemoException;

    public de.doubleslash.model.Demo updateImpl(de.doubleslash.model.Demo demo)
        throws com.liferay.portal.kernel.exception.SystemException;

    /**
    * Returns the demo with the primary key or throws a {@link de.doubleslash.NoSuchDemoException} if it could not be found.
    *
    * @param demoId the primary key of the demo
    * @return the demo
    * @throws de.doubleslash.NoSuchDemoException if a demo with the primary key could not be found
    * @throws SystemException if a system exception occurred
    */
    public de.doubleslash.model.Demo findByPrimaryKey(long demoId)
        throws com.liferay.portal.kernel.exception.SystemException,
            de.doubleslash.NoSuchDemoException;

    /**
    * Returns the demo with the primary key or returns <code>null</code> if it could not be found.
    *
    * @param demoId the primary key of the demo
    * @return the demo, or <code>null</code> if a demo with the primary key could not be found
    * @throws SystemException if a system exception occurred
    */
    public de.doubleslash.model.Demo fetchByPrimaryKey(long demoId)
        throws com.liferay.portal.kernel.exception.SystemException;

    /**
    * Returns all the demos.
    *
    * @return the demos
    * @throws SystemException if a system exception occurred
    */
    public java.util.List<de.doubleslash.model.Demo> findAll()
        throws com.liferay.portal.kernel.exception.SystemException;

    /**
    * Returns a range of all the demos.
    *
    * <p>
    * Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link de.doubleslash.model.impl.DemoModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
    * </p>
    *
    * @param start the lower bound of the range of demos
    * @param end the upper bound of the range of demos (not inclusive)
    * @return the range of demos
    * @throws SystemException if a system exception occurred
    */
    public java.util.List<de.doubleslash.model.Demo> findAll(int start, int end)
        throws com.liferay.portal.kernel.exception.SystemException;

    /**
    * Returns an ordered range of all the demos.
    *
    * <p>
    * Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link de.doubleslash.model.impl.DemoModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
    * </p>
    *
    * @param start the lower bound of the range of demos
    * @param end the upper bound of the range of demos (not inclusive)
    * @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
    * @return the ordered range of demos
    * @throws SystemException if a system exception occurred
    */
    public java.util.List<de.doubleslash.model.Demo> findAll(int start,
        int end,
        com.liferay.portal.kernel.util.OrderByComparator orderByComparator)
        throws com.liferay.portal.kernel.exception.SystemException;

    /**
    * Removes all the demos from the database.
    *
    * @throws SystemException if a system exception occurred
    */
    public void removeAll()
        throws com.liferay.portal.kernel.exception.SystemException;

    /**
    * Returns the number of demos.
    *
    * @return the number of demos
    * @throws SystemException if a system exception occurred
    */
    public int countAll()
        throws com.liferay.portal.kernel.exception.SystemException;
}
